"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = void 0;
const ConnectionError_1 = require("./ConnectionError");
const ManagedConnection_1 = require("./ManagedConnection");
class Connection extends ManagedConnection_1.ManagedConnection {
    /** INTERNAL, DO NOT USE DIRECTLY */
    constructor(poolConnection, logger, releaseStrategy) {
        super(poolConnection, logger);
        this.releaseStrategy = releaseStrategy;
    }
    /**
     * Release current connection back to the pool according to selected connection release strategy
     */
    async release() {
        if (this.closed) {
            return;
        }
        if (this.busy) {
            throw new ConnectionError_1.ConnectionError(`Unable to release a connection while an operation is in progress`);
        }
        this.closed = true;
        const promise = this.releaseToPool();
        if (this.logger.release) {
            this.logger.release(this.poolConnection.threadId);
        }
        if (this.releaseStrategy === 'WAIT_FOR_STATE_RESET') {
            await promise;
        }
    }
    /** INTERNAL, DO NOT USE DIRECTLY */
    async releaseToPool() {
        if (this.releaseStrategy !== 'KEEP_STATE') {
            try {
                await this.poolConnection.changeUser({});
            }
            catch (err) {
                // ignore change user errors as they'll invalidate the connection when reaching pool
            }
        }
        this.poolConnection.release();
    }
    /** Is the connection released */
    get isReleased() {
        return this.closed;
    }
}
exports.Connection = Connection;
