import { Connection } from './Connection';
import { type ConnectionManagerOptions } from "./ConnectionManagerOptions";
import { ManagedConnection } from './ManagedConnection';
import { Session } from './Session';
import { ManagedSession } from './ManagedSession';
import { ConnectionOptions } from './ConnectionOptions';
export declare class ConnectionManager {
    private pool;
    private closed;
    private logger;
    private releaseStrategy;
    /** Create a new connection manager with given options */
    constructor(options: ConnectionManagerOptions);
    /** Run the handler within an automatically managed connection */
    connection<T>(handler: (connection: ManagedConnection) => Promise<T>, options?: ConnectionOptions): Promise<T>;
    /** Run the handler within an automatically managed session */
    session<T>(handler: (session: ManagedSession) => Promise<T>, options?: ConnectionOptions): Promise<T>;
    /** Get a manually managed connection (do not forget to release it when done) */
    getConnection(options?: ConnectionOptions): Promise<Connection>;
    /** Get a manually managed session (unlike connection, closing a session is completely optional) */
    getSession(options?: ConnectionOptions): Session;
    /** Close the connection manager, gracefully close all connections and stop waiting for new ones */
    close(): Promise<void>;
    /** Is the connection manager closed */
    get isClosed(): boolean;
}
