"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Formatter = void 0;
const mysql2 = require('mysql2');
const formatThis = {
    config: { namedPlaceholders: true },
    _resolveNamedPlaceholders: mysql2.Connection.prototype._resolveNamedPlaceholders
};
class Formatter {
    /**
     * Escape a value
     * @see https://github.com/mysqljs/mysql#escaping-query-values
     */
    static escape(value) {
        return mysql2.escape(value);
    }
    /**
     * Escape an identifier (e.g. table or column name) with backticks
     */
    static escapeId(id) {
        return mysql2.escapeId(id);
    }
    /**
     * Format SQL replacing placeholders with appropriate parameters
     */
    static format(sql, parameters) {
        return mysql2.Connection.prototype.format.call(formatThis, sql, parameters);
    }
    /**
     * Get SQL as-is to be used as a parameter
     */
    static raw(sql) {
        return { toSqlString: () => sql };
    }
}
exports.Formatter = Formatter;
