import { ConnectionManager } from "./ConnectionManager";
import { ConnectionOptions } from "./ConnectionOptions";
import { Escapable, Queryable, QueryParameters } from "./Queryable";
import { Transaction } from "./Transaction";
import { TransactionOptions } from "./TransactionOptions";
export declare class ManagedSession implements Queryable {
    private connectionManager;
    private settings;
    protected closed: boolean;
    /** INTERNAL, DO NOT USE DIRECTLY */
    constructor(connectionManager: ConnectionManager, settings: Required<ConnectionOptions>);
    /**
     * Escape a value
     * @see https://github.com/mysqljs/mysql#escaping-query-values
     */
    escape(value: Escapable): string;
    /**
     * Escape an identifier (e.g. table or column name) with backticks
     */
    escapeId(id: string): string;
    /** Execute a query with given parameters in an automatically managed connection temporarily acquired from pool */
    query(sql: string, parameters?: QueryParameters): Promise<import("./QueryResult").QueryResult>;
    /** Execute the handler in an automatically managed transaction within a temporary connection acquired from pool */
    transaction<T>(handler: (tx: Transaction) => Promise<T>, options?: TransactionOptions): Promise<T>;
}
