import { PoolConnection } from 'mysql2/promise';
import { Logger } from './Logger';
import { Escapable, Queryable, QueryParameters } from './Queryable';
import { QueryResult } from './QueryResult';
export declare class QueryExecutor implements Queryable {
    protected poolConnection: PoolConnection;
    protected logger: Logger;
    protected inTx: boolean;
    protected busy: boolean;
    protected closed: boolean;
    protected constructor(poolConnection: PoolConnection, logger: Logger);
    /**
     * Escape a value
     * @see https://github.com/mysqljs/mysql#escaping-query-values
     */
    escape(value: Escapable): string;
    /**
     * Escape an identifier (e.g. table or column name) with backticks
     */
    escapeId(id: string): string;
    /** Execute a query with given parameters */
    query(sql: string, parameters?: QueryParameters): Promise<QueryResult>;
    /** Is the current query executor busy with executing a query */
    get isBusy(): boolean;
}
