"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryResult = void 0;
const QueryError_1 = require("./QueryError");
class QueryResult {
    /** INTERNAL, DO NOT USE DIRECTLY */
    constructor(fields, data, next) {
        this.next = next;
        this.columns = Array.isArray(fields)
            ? fields.map(field => convertColumnDefinition(field))
            : [];
        if (Array.isArray(data)) {
            this.rows = data;
            this.lastInsertId = '0';
            this.affectedRows = 0;
            this.warningsCount = 0;
        }
        else {
            this.rows = [];
            this.lastInsertId = String(data.insertId);
            this.affectedRows = parseFloat(data.affectedRows);
            this.warningsCount = parseFloat(data.warningStatus);
        }
    }
    get isResultSet() {
        return this.columns.length > 0;
    }
    /** Translate the result into an array of objects, optionally prefixing each field with table and/or schema name */
    asObjects(tableNameSeparator, schemaNameSeparator) {
        return this.rows.map((fields) => {
            const obj = {};
            for (let i = 0; i < fields.length; i++) {
                const schemaPrefix = typeof schemaNameSeparator === 'string'
                    ? `${this.columns[i].schema}${schemaNameSeparator}`
                    : ``;
                const tablePrefix = typeof tableNameSeparator === 'string'
                    ? `${this.columns[i].table}${tableNameSeparator}`
                    : ``;
                obj[`${schemaPrefix}${tablePrefix}${this.columns[i].name}`] = fields[i];
            }
            return obj;
        });
    }
    /** Get the next result of a multi-statement query */
    async getNextResult() {
        if (this.next === null) {
            throw new QueryError_1.QueryError(`There is no next result available`);
        }
        return this.next;
    }
    /** Whether there may be a next result in a multi-statement query */
    get hasNextResult() {
        return this.next !== null;
    }
}
exports.QueryResult = QueryResult;
function convertColumnDefinition(def) {
    return {
        schema: def._buf.toString(def._clientEncoding, def._schemaStart, def._schemaStart + def._schemaLength),
        table: def._buf.toString(def._clientEncoding, def._tableStart, def._tableStart + def._tableLength),
        name: def.name
    };
}
