"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Transaction = void 0;
const QueryExecutor_1 = require("./QueryExecutor");
const TransactionError_1 = require("./TransactionError");
class Transaction extends QueryExecutor_1.QueryExecutor {
    /** INTERNAL, DO NOT USE DIRECTLY */
    static async start(poolConnection, logger, mode) {
        const tx = new Transaction(poolConnection, logger);
        await tx.internalQuery(`START TRANSACTION${mode === 'READ' ? ' READ ONLY' : mode === 'WRITE' ? ' READ WRITE' : ''}`);
        return tx;
    }
    /** INTERNAL, DO NOT USE DIRECTLY */
    static async commit(tx) {
        if (!tx.inTx) {
            tx.closed = true;
            throw new TransactionError_1.TransactionError(`Transaction has been prematurely committed or rolled back`);
        }
        try {
            await tx.internalQuery(`COMMIT`);
        }
        finally {
            tx.closed = true;
        }
    }
    /** INTERNAL, DO NOT USE DIRECTLY */
    static async rollback(tx) {
        if (!tx.inTx) {
            tx.closed = true;
            throw new TransactionError_1.TransactionError(`Transaction has been prematurely committed or rolled back`);
        }
        try {
            await tx.internalQuery(`ROLLBACK`);
        }
        finally {
            tx.closed = true;
        }
    }
    query(sql, parameters) {
        if (!this.inTx) {
            throw new TransactionError_1.TransactionError(`Transaction is inactive and can not perform operations`);
        }
        return super.query(sql, parameters);
    }
    get isActive() {
        return this.inTx && !this.closed;
    }
    internalQuery(sql) {
        return super.query(sql);
    }
}
exports.Transaction = Transaction;
