import { Escapable, QueryParameters, QueryRawValue } from "./Queryable";

const mysql2 = require('mysql2');
const formatThis = {
	config: { namedPlaceholders: true },
	_resolveNamedPlaceholders: mysql2.Connection.prototype._resolveNamedPlaceholders
};

export abstract class Formatter {

	/**
	 * Escape a value
	 * @see https://github.com/mysqljs/mysql#escaping-query-values
	 */
	public static escape(value: Escapable): string {
		return mysql2.escape(value);
	}

	/**
	 * Escape an identifier (e.g. table or column name) with backticks
	 */
	public static escapeId(id: string): string {
		return mysql2.escapeId(id);
	}

	/**
	 * Format SQL replacing placeholders with appropriate parameters
	 */
	public static format(sql: string, parameters?: QueryParameters): string {
		return mysql2.Connection.prototype.format.call(formatThis, sql, parameters);
	}

	/**
	 * Get SQL as-is to be used as a parameter
	 */
	public static raw(sql: string): QueryRawValue {
		return { toSqlString: () => sql };
	}

}