import { QueryResult } from "./QueryResult";

type QueryScalarValue = Buffer | string | number | boolean | null | undefined;

type QueryObjectValue = {
	[k: string]: QueryScalarValue
}

/** A valid dynamic raw value to be used as a parameter */
export interface QueryRawValue {
	toSqlString(): string;
}

/** A valid escapable value */
export type Escapable =
	| QueryScalarValue
	| QueryScalarValue[]
	| QueryScalarValue[][]
	| QueryObjectValue
	| QueryRawValue;

/** A list of appropriate query parameters */
export type QueryParameters = {
	[k: string]: Escapable
}

export interface Queryable {

	/**
	 * Escape a value
	 * @see https://github.com/mysqljs/mysql#escaping-query-values
	 */
	escape(value: Escapable): string;

	/**
	 * Escape an identifier (e.g. table or column name) with backticks
	 */
	escapeId(id: string): string;

	/** Execute a query with given parameters */
	query(sql: string, parameters?: QueryParameters): Promise<QueryResult>;

}
